/*
 * Copyright (C) 2015 Darron Broad
 * All rights reserved.
 * 
 * This file is part of miniblink.
 * 
 * miniblink is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation. 
 * 
 * miniblink is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details. 
 * 
 * You should have received a copy of the GNU General Public License along
 * with miniblink. If not, see http://www.gnu.org/licenses/
 */

/*
 * RM0016
 * Reference manual
 *
 * STM8S and STM8AF microcontroller families 
 *
 * CD00190271.pdf
 */

#ifndef _STM8_H
#define _STM8_H

#include <stdint.h>

/*
 * 9.10 Clock register map
 *
 * Page: 101
 */

#define CLK_ICKR     *(volatile uint8_t *)(0x50C0)
#define CLK_ECKR     *(volatile uint8_t *)(0x50C1)
/* RESERVED */
#define CLK_CMSR     *(volatile uint8_t *)(0x50C3)
#define CLK_SWR      *(volatile uint8_t *)(0x50C4)
#define CLK_SWCR     *(volatile uint8_t *)(0x50C5)
#define CLK_CKDIVR   *(volatile uint8_t *)(0x50C6)
#define CLK_PCKENR1  *(volatile uint8_t *)(0x50C7)
#define CLK_CSSR     *(volatile uint8_t *)(0x50C8)
#define CLK_CCOR     *(volatile uint8_t *)(0x50C9)
#define CLK_PCKENR2  *(volatile uint8_t *)(0x50CA)
/* RESERVED */
#define CLK_HSITRIMR *(volatile uint8_t *)(0x50CC)
#define CLK_SWIMCCR  *(volatile uint8_t *)(0x50CD)

/*
 * 11.9 GPIO registers
 *
 * Page: 112
 */
#define PA_ODR *(volatile uint8_t *)(0x5000)
#define PA_IDR *(volatile uint8_t *)(0x5001)
#define PA_DDR *(volatile uint8_t *)(0x5002)
#define PA_CR1 *(volatile uint8_t *)(0x5003)
#define PA_CR2 *(volatile uint8_t *)(0x5004)

#define PB_ODR *(volatile uint8_t *)(0x5005)
#define PB_IDR *(volatile uint8_t *)(0x5006)
#define PB_DDR *(volatile uint8_t *)(0x5007)
#define PB_CR1 *(volatile uint8_t *)(0x5008)
#define PB_CR2 *(volatile uint8_t *)(0x5009)

#define PC_ODR *(volatile uint8_t *)(0x500A)
#define PC_IDR *(volatile uint8_t *)(0x500B)
#define PC_DDR *(volatile uint8_t *)(0x500C)
#define PC_CR1 *(volatile uint8_t *)(0x500D)
#define PC_CR2 *(volatile uint8_t *)(0x500E)

#define PD_ODR *(volatile uint8_t *)(0x500F)
#define PD_IDR *(volatile uint8_t *)(0x5010)
#define PD_DDR *(volatile uint8_t *)(0x5011)
#define PD_CR1 *(volatile uint8_t *)(0x5012)
#define PD_CR2 *(volatile uint8_t *)(0x5013)

#define PE_ODR *(volatile uint8_t *)(0x5014)
#define PE_IDR *(volatile uint8_t *)(0x5015)
#define PE_DDR *(volatile uint8_t *)(0x5016)
#define PE_CR1 *(volatile uint8_t *)(0x5017)
#define PE_CR2 *(volatile uint8_t *)(0x5018)

#define PF_ODR *(volatile uint8_t *)(0x5019)
#define PF_IDR *(volatile uint8_t *)(0x501A)
#define PF_DDR *(volatile uint8_t *)(0x501B)
#define PF_CR1 *(volatile uint8_t *)(0x501C)
#define PF_CR2 *(volatile uint8_t *)(0x501D)

#endif
